<option value="none" selected="selected" label="Select an option">Select an option</option>
<option value="windows" label="Microsoft Windows">Microsoft Windows</option>
<option value="macosx" label="Apple Mac OS X">Apple Mac OS X</option>
<option value="rhel" label="Red Hat Enterprise Linux">Red Hat Enterprise Linux</option>
<option value="centos" label="CentOS">CentOS</option>
<option value="fedora" label="Fedora">Fedora</option>
<option value="scilinux" label="Scientific Linux">Scientific Linux</option>
<option value="debian" label="Debian">Debian</option>
<option value="ubuntu" label="Ubuntu">Ubuntu</option>
<option value="biolinux" label="BioLinux">BioLinux</option>
<option value="slel" label="Suse Enterprise Linux">Suse Enterprise Linux</option>
<option value="suse" label="OpenSuse">OpenSuse</option>
<option value="gentoo" label="Gentoo">Gentoo</option>
<option value="mandriva" label="Mandriva">Mandriva</option>
<option value="arch" label="Arch Linux">Arch Linux</option>
<option value="slackware" label="Slackware">Slackware</option>
<option value="otherlinux" label="Other GNU/Linux distribution">Other GNU/Linux distribution</option>
<option value="starbsd" label="FreeBSD/OpenBSD/NetBSD">FreeBSD/OpenBSD/NetBSD</option>
<option value="unix" label="HP-UX/AIX/SCO/BSD">HP-UX/AIX/SCO/BSD</option>
<option value="qnx" label="QNX">QNX</option>
<option value="beos" label="BeOS">BeOS</option>
<option value="solaris" label="Solaris">Solaris</option>
<option value="other" label="Other operating system">Other operating system</option>
<option value="dontknow" label="I don't know">I don't know</option>
